const APP = {
  config: {
    env: process.env.APP_ENV,
    apiUrl: process.env.APP_API
  }
}

export { APP }
